<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>DecoderSndFileFactory</name>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="66"/>
        <source>Sndfile Plugin</source>
        <translation>Модуль Sndfile</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="68"/>
        <source>PCM Files</source>
        <translation>Файлы PCM</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="136"/>
        <source>About Sndfile Audio Plugin</source>
        <translation>Об аудио-модуле Sndfile</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="137"/>
        <source>Qmmp Sndfile Audio Plugin</source>
        <translation>Модуль SndFile для Qmmp</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="138"/>
        <source>Compiled against</source>
        <translation>Собрано с</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="139"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
